==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/vmware/src/Plugin/QueueWorker/VmwareUpdateResourcesQueueWorker.php <==
<?php

namespace Drupal\vmware\Plugin\QueueWorker;

use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\vmware\Service\VmwareServiceException;
use Drupal\vmware\Service\VmwareServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Vmware Update Resources Queue.
 *
 * @QueueWorker(
 *   id = "vmware_update_resources_queue",
 *   title = @Translation("Vmware Update Resources Queue"),
 * )
 */
class VmwareUpdateResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  use CloudContentEntityTrait;

  /**
   * The vmware service.
   *
   * @var \Drupal\vmware\Service\VmwareServiceInterface
   */
  private $vmwareService;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\vmware\Service\VmwareServiceInterface $vmware_service
   *   The vmware service.
   */
  public function __construct(array $configuration, $plugin_id, array $plugin_definition, VmwareServiceInterface $vmware_service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->vmwareService = $vmware_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('vmware')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $cloud_context = $data['cloud_context'];
    $vmware_method_name = $data['vmware_method_name'];

    if (!method_exists($this->vmwareService, $vmware_method_name)) {
      $this->logger('vmware_service')->error($this->t("The method @vmware_method_name does not exist in class VmwareService.",
      [
        '@vmware_method_name' => $vmware_method_name,
      ]));
      return;
    }

    try {
      $this->vmwareService->setCloudContext($cloud_context);

      if (empty($this->vmwareService->getSessionId())) {
        $this->vmwareService->login();
      }
      $updated = $this->vmwareService->$vmware_method_name();
    }
    catch (VmwareServiceException $e) {
      $updated = FALSE;
    }

    if (empty($updated)) {
      $this->logger('vmware_service')->info('Unable to update resource with error @error.',
      [
        '@error' => $e->getMessage(),
      ]);
      return;
    }

    $this->logger('vmware_service')->info('Updated resource in @context.', ['@context' => $cloud_context]);
  }

}

==> cloud-4.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/vmware/src/Plugin/QueueWorker/VmwareUpdateResourcesQueueWorker.php <==
<?php

namespace Drupal\vmware\Plugin\QueueWorker;

use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\vmware\Service\VmwareServiceException;
use Drupal\vmware\Service\VmwareServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Vmware Update Resources Queue.
 *
 * @QueueWorker(
 *   id = "vmware_update_resources_queue",
 *   title = @Translation("Vmware Update Resources Queue"),
 * )
 */
class VmwareUpdateResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  use CloudContentEntityTrait;

  /**
   * The vmware service.
   *
   * @var \Drupal\vmware\Service\VmwareServiceInterface
   */
  private $vmwareService;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\vmware\Service\VmwareServiceInterface $vmware_service
   *   The vmware service.
   */
  public function __construct(array $configuration, $plugin_id, array $plugin_definition, VmwareServiceInterface $vmware_service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->vmwareService = $vmware_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('vmware')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $cloud_context = $data['cloud_context'];
    $vmware_method_name = $data['vmware_method_name'];

    if (!method_exists($this->vmwareService, $vmware_method_name)) {
      $this->logger('vmware_service')->error($this->t("The method @vmware_method_name does not exist in class VmwareService.",
      [
        '@vmware_method_name' => $vmware_method_name,
      ]));
      return;
    }

    try {
      $this->vmwareService->setCloudContext($cloud_context);

      if (empty($this->vmwareService->getSessionId())) {
        $this->vmwareService->login();
      }

      if (empty($this->vmwareService->$vmware_method_name())) {
        $this->logger('vmware_service')
          ->error($this->t('Unable to update resource.'));
        return;
      }
    }
    catch (VmwareServiceException $e) {
      $this->logger('vmware_service')
        ->error($this->t('An error occurred: @exception.', [
          '@exception' => $e->getMessage(),
        ]));
      return;
    }

    $this->logger('vmware_service')
      ->info($this->t('Updated resource in @context.', [
        '@context' => $cloud_context,
      ]));
  }

}
